@@ -9,12 +9,12 @@ use strict ;
 use warnings;
 use bytes;
 
-use IO::Uncompress::RawInflate 2.055 ;
+use IO::Uncompress::RawInflate 2.057 ;
 
-use Compress::Raw::Zlib 2.055 () ;
-use IO::Compress::Base::Common 2.055 qw(:Status createSelfTiedObject);
-use IO::Compress::Gzip::Constants 2.055 ;
-use IO::Compress::Zlib::Extra 2.055 ;
+use Compress::Raw::Zlib 2.057 () ;
+use IO::Compress::Base::Common 2.057 qw(:Status );
+use IO::Compress::Gzip::Constants 2.057 ;
+use IO::Compress::Zlib::Extra 2.057 ;
 
 require Exporter ;
 
@@ -28,27 +28,26 @@ Exporter::export_ok_tags('all');
 
 $GunzipError = '';
 
-$VERSION = '2.055';
+$VERSION = '2.057';
 
 sub new
 {
     my $class = shift ;
     $GunzipError = '';
-    my $obj = createSelfTiedObject($class, \$GunzipError);
+    my $obj = IO::Compress::Base::Common::createSelfTiedObject($class, \$GunzipError);
 
     $obj->_create(undef, 0, @_);
 }
 
 sub gunzip
 {
-    my $obj = createSelfTiedObject(undef, \$GunzipError);
+    my $obj = IO::Compress::Base::Common::createSelfTiedObject(undef, \$GunzipError);
     return $obj->_inf(@_) ;
 }
 
 sub getExtraParams
 {
-    use IO::Compress::Base::Common  2.055 qw(:Parse);
-    return ( 'ParseExtra' => [1, 1, Parse_boolean,  0] ) ;
+    return ( 'parseextra' => [IO::Compress::Base::Common::Parse_boolean,  0] ) ;
 }
 
 sub ckParams
@@ -57,7 +56,7 @@ sub ckParams
     my $got = shift ;
 
     # gunzip always needs crc32
-    $got->value('CRC32' => 1);
+    $got->setValue('crc32' => 1);
 
     return 1;
 }
@@ -923,6 +922,13 @@ Provides a sub-set of the C<seek> functionality, with the restriction
 that it is only legal to seek forward in the input file/buffer.
 It is a fatal error to attempt to seek backward.
 
+Note that the implementation of C<seek> in this module does not provide
+true random access to a compressed file/buffer. It  works by uncompressing
+data from the current offset in the file/buffer until it reaches the
+ucompressed offset specified in the parameters to C<seek>. For very small
+files this may be acceptable behaviour. For large files it may cause an
+unacceptable delay.
+
 The C<$whence> parameter takes one the usual values, namely SEEK_SET,
 SEEK_CUR or SEEK_END.
 
