@@ -9,21 +9,21 @@ use warnings;
 use bytes;
 
 use IO::File;
-use IO::Uncompress::RawInflate  2.049 ;
-use IO::Compress::Base::Common  2.049 qw(:Status createSelfTiedObject);
-use IO::Uncompress::Adapter::Inflate  2.049 ;
-use IO::Uncompress::Adapter::Identity 2.049 ;
-use IO::Compress::Zlib::Extra 2.049 ;
-use IO::Compress::Zip::Constants 2.049 ;
+use IO::Uncompress::RawInflate  2.057 ;
+use IO::Compress::Base::Common  2.057 qw(:Status );
+use IO::Uncompress::Adapter::Inflate  2.057 ;
+use IO::Uncompress::Adapter::Identity 2.057 ;
+use IO::Compress::Zlib::Extra 2.057 ;
+use IO::Compress::Zip::Constants 2.057 ;
 
-use Compress::Raw::Zlib  2.049 () ;
+use Compress::Raw::Zlib  2.057 () ;
 
 BEGIN
 {
-    eval { require IO::Uncompress::Adapter::Bunzip2 ;
+    eval{ require IO::Uncompress::Adapter::Bunzip2 ;
            import  IO::Uncompress::Adapter::Bunzip2 } ;
-   eval { require IO::Uncompress::Adapter::UnLzma ;
-           import  IO::Uncompress::Adapter::UnLzma } ;
+    eval{ require IO::Uncompress::Adapter::UnLzma ;
+          import  IO::Uncompress::Adapter::UnLzma } ;
 }
 
 
@@ -31,7 +31,7 @@ require Exporter ;
 
 our ($VERSION, @ISA, @EXPORT_OK, %EXPORT_TAGS, $UnzipError, %headerLookup);
 
-$VERSION = '2.049';
+$VERSION = '2.057';
 $UnzipError = '';
 
 @ISA    = qw(Exporter IO::Uncompress::RawInflate);
@@ -52,27 +52,25 @@ Exporter::export_ok_tags('all');
 sub new
 {
     my $class = shift ;
-    my $obj = createSelfTiedObject($class, \$UnzipError);
+    my $obj = IO::Compress::Base::Common::createSelfTiedObject($class, \$UnzipError);
     $obj->_create(undef, 0, @_);
 }
 
 sub unzip
 {
-    my $obj = createSelfTiedObject(undef, \$UnzipError);
+    my $obj = IO::Compress::Base::Common::createSelfTiedObject(undef, \$UnzipError);
     return $obj->_inf(@_) ;
 }
 
 sub getExtraParams
 {
-    use IO::Compress::Base::Common  2.049 qw(:Parse);
-
-    
+   
     return (
 #            # Zip header fields
-            'Name'    => [1, 1, Parse_any,       undef],
-
-            'Stream' => [1, 1, Parse_boolean,   0],
+            'name'    => [IO::Compress::Base::Common::Parse_any,       undef],
 
+            'stream'  => [IO::Compress::Base::Common::Parse_boolean,   0],
+            
             # TODO - This means reading the central directory to get
             # 1. the local header offsets
             # 2. The compressed data length
@@ -85,9 +83,9 @@ sub ckParams
     my $got = shift ;
 
     # unzip always needs crc32
-    $got->value('CRC32' => 1);
+    $got->setValue('crc32' => 1);
 
-    *$self->{UnzipData}{Name} = $got->value('Name');
+    *$self->{UnzipData}{Name} = $got->getValue('name');
 
     return 1;
 }
@@ -1403,7 +1401,7 @@ The string '-' can be used as an alias for standard input.
 =item A scalar reference 
 
 If C<$input> is a scalar reference, the compressed data will be read from
-C<$$output>.
+C<$$input>.
 
 =back
 
@@ -1623,6 +1621,13 @@ Provides a sub-set of the C<seek> functionality, with the restriction
 that it is only legal to seek forward in the input file/buffer.
 It is a fatal error to attempt to seek backward.
 
+Note that the implementation of C<seek> in this module does not provide
+true random access to a compressed file/buffer. It  works by uncompressing
+data from the current offset in the file/buffer until it reaches the
+ucompressed offset specified in the parameters to C<seek>. For very small
+files this may be acceptable behaviour. For large files it may cause an
+unacceptable delay.
+
 The C<$whence> parameter takes one the usual values, namely SEEK_SET,
 SEEK_CUR or SEEK_END.
 
@@ -1769,7 +1774,7 @@ Same as doing this
 
 =head2 Working with Net::FTP
 
-See L<IO::Uncompress::Unzip::FAQ|IO::Uncompress::Unzip::FAQ/"Compressed files and Net::FTP">
+See L<IO::Compress::FAQ|IO::Compress::FAQ/"Compressed files and Net::FTP">
 
 =head2 Walking through a zip file
 
@@ -1783,7 +1788,7 @@ stream at a time.
         or die "Cannot open $zipfile: $UnzipError";
 
     my $status;
-    for ($status = 1; $stream > 0; $status = $u->nextStream())
+    for ($status = 1; $status > 0; $status = $u->nextStream())
     {
  
         my $name = $u->getHeaderInfo()->{Name};
